@@ -113,7 +113,7 @@ def main():
     from cola.controllers.classic import cola_classic
     from cola.app import ColaApplication
     from cola import qtutils
-    from cola import commands
+    from cola import cmds
 
 
     # Allow Ctrl-C to exit
@@ -149,7 +149,7 @@ def main():
         _setup_resource_dir(resources.style_dir())
 
     # Register model commands
-    commands.register()
+    cmds.register()
 
     # Ensure that we're working in a valid git repository.
     # If not, try to find one.  When found, chdir there.
@@ -178,11 +178,12 @@ def main():
     # Start the inotify thread
     inotify.start()
 
+    # Show the view and start the main event loop
+    view.show()
+
     # Make sure that we start out on top
     view.raise_()
 
-    # Show the view and start the main event loop
-    view.show()
     git.GIT_COLA_TRACE = os.getenv('GIT_COLA_TRACE', False)
     if git.GIT_COLA_TRACE:
         msg = ('info: Trace enabled.  '
